nvmereceiver

package module
v0.0.0-...-8cc0a85 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: Apache-2.0 Imports: 18 Imported by: 0

README

otel-nvme-receiver is a receiver of OpenTelemetry Collector to collect NVMe metrics with the help of nvme-cli tool.

This is repackaged fork of elek/nvme_exporter which is a fork of the original nvme_exporter.

Documentation

Overview

This file is the refactored version of https://github.com/open-telemetry/opentelemetry-go-contrib/blob/bridges/prometheus/v0.63.0/bridges/prometheus/producer.go

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFactory

func NewFactory() receiver.Factory

Types

type Config

type Config struct {
	Interval        string `mapstructure:"interval"`
	TemperatureUnit string `mapstructure:"temperature_unit"`
}

type NvmeReceiver

type NvmeReceiver struct {
	// contains filtered or unexported fields
}

func (*NvmeReceiver) Shutdown

func (s *NvmeReceiver) Shutdown(ctx context.Context) error

func (*NvmeReceiver) Start

func (s *NvmeReceiver) Start(ctx context.Context, host component.Host) error

type Option

type Option interface {
	// contains filtered or unexported methods
}

Option sets producer option values.

func WithGatherer

func WithGatherer(gatherer prometheus.Gatherer) Option

WithGatherer configures which prometheus Gatherer the Bridge will gather from. If no registerer is used the prometheus DefaultGatherer is used.

func WithScope

func WithScope(scope string) Option

type Producer

type Producer struct {
	// contains filtered or unexported fields
}

func NewMetricProducer

func NewMetricProducer(opts ...Option) *Producer

NewMetricProducer returns a metric.Producer that fetches metrics from Prometheus. This can be used to allow Prometheus instrumentation to be added to an OpenTelemetry export pipeline.

func (*Producer) Produce

func (p *Producer) Produce(context.Context) (pmetric.Metrics, error)

Jump to